@@ -18,6 +18,36 @@ if settings.DEBUG:
 
 POOL_SETTINGS = getattr(settings, 'DJORM_POOL_OPTIONS', {})
 
+
+class hashabledict(dict):
+    def __hash__(self):
+        return hash(tuple(sorted(self.items())))
+
+
+class hashablelist(list):
+    def __hash__(self):
+        return hash(tuple(sorted(self)))
+
+
+class ManagerProxy(object):
+    def __init__(self, manager):
+        self.manager = manager
+
+    def __getattr__(self, key):
+        return getattr(self.manager, key)
+
+    def connect(self, *args, **kwargs):
+        if 'conv' in kwargs:
+            conv = kwargs['conv']
+            if isinstance(conv, dict):
+                items = []
+                for k, v in conv.items():
+                    if isinstance(v, list):
+                        v = hashablelist(v)
+                    items.append((k, v))
+                kwargs['conv'] = hashabledict(items)
+        return self.manager.connect(*args, **kwargs)
+
 try:
     from django.db.backends.postgresql_psycopg2 import base as pgsql_base
     pgsql_base._Database = pgsql_base.Database
@@ -29,7 +59,8 @@ except ImproperlyConfigured:
 try:
     from django.db.backends.mysql import base as mysql_base
     mysql_base._Database = mysql_base.Database
-    mysql_base.Database = manage(mysql_base._Database, **POOL_SETTINGS)
+    db = ManagerProxy(manage(mysql_base._Database, **POOL_SETTINGS))
+    mysql_base.Database = db
 except ImproperlyConfigured:
     pass
 
